@@ -41,7 +41,7 @@ class ScribeClient:
                 return True
             return (datetime.datetime.now() - last_update).days > 1
 
-    def __init__(self, api_token=None, ignore_env = True, base_url="https://api.scribesecurity.com", refresh_interval=600, cached_data={}):
+    def __init__(self, api_token=None, ignore_env = False, base_url="https://api.scribesecurity.com", refresh_interval=600, cached_data={}):
         def update_from_cached_data(cached_data):
             if "datasets" in cached_data:
                 self.datasets = cached_data["datasets"]
@@ -65,7 +65,11 @@ class ScribeClient:
         if ignore_env:
             self.api_token = api_token
         else:
-            self.api_token = api_token or os.getenv('SCRIBE_TOKEN')
+            self.api_token = api_token or os.getenv('SCRIBE_TOKEN', None)
+        if not self.api_token:
+            logging.error("No API token provided. Please set the SCRIBE_TOKEN environment variable or pass it as an argument.")
+            return
+        
         self.base_url = base_url
         self.refresh_interval = refresh_interval
         self.last_refresh = datetime.datetime.now() - datetime.timedelta(days=5)  # Initialize to a time in the past
